@@ -333,7 +333,7 @@ def spilt_chinese_and_english(strings):
     return string_
 
 
-class BasePlot(object):
+class _BasePlot(object):
     """
     基础画图。
 
@@ -349,23 +349,6 @@ class BasePlot(object):
 
     """
 
-    def __init__(self, font="Arial", figure_size=(10, 7.5), types="single"):
-        """
-
-        Args:
-            font: (str), 字体。如：【Arial,DejaVu Sans,宋体+Times,宋体，Times】
-            figure_size:(tuple) 图片大小。
-            types:(str) 图片种类: 如：【single,long,part】
-        """
-        if types == "single":
-            setting_rcParams_single(font=font, figure_size=figure_size)
-        elif types == "long":
-            setting_rcParams_long(font=font, figure_size=figure_size)
-        elif types == "part":
-            setting_rcParams_part(font=font, figure_size=figure_size)
-        else:
-            setting_rcParams_single(font=font, figure_size=figure_size)
-
     @staticmethod
     def base_axes():
         fig = plt.figure()
@@ -378,7 +361,7 @@ class BasePlot(object):
         return plt
 
     @staticmethod
-    def scatter(x, y, strx='x', stry='y_predict', line_45=False,color="orange"):
+    def scatter(x, y, strx='x', stry='y_predict', line_45=False, color="orange"):
         """
         散点图
         """
@@ -746,7 +729,6 @@ class BasePlot(object):
         binary_distance[indexs[:, 1], indexs[:, 0]] = t
         return binary_distance
 
-
     def distance(self, node_color, edge_color_pen=0.7, binary_distance=None, print_noise=0.001,
                  node_name=None, highlight=None):
         """
@@ -793,7 +775,7 @@ class BasePlot(object):
             lab = {i: i for i in range(le)}
 
         elif node_name is False:
-            lab=None
+            lab = None
 
         else:
             assert binary_distance.shape[0]
@@ -824,3 +806,54 @@ class BasePlot(object):
                 )
 
         return plt
+
+
+class QPlot(_BasePlot):
+    """
+    Quick temporary display.
+
+    >>> bp = QPlot()
+    >>> plt = bp.scatter_45_line(x, y_predict, strx='x', stry='y_predict')
+    >>> plt.show()
+    >>> plt = bp.line_scatter(y_scatter, y_lines, strx='x', stry='ys')
+    >>> plt.show()
+    >>> plt = bp.lines(ys)
+    >>> plt.show()
+    >>> plt = bp.lines(ys,x)
+    >>> plt.show()
+
+    """
+
+
+class BasePlot(_BasePlot):
+    """
+    基础画图。
+
+    >>> bp = BasePlot()
+    >>> plt = bp.scatter_45_line(x, y_predict, strx='x', stry='y_predict')
+    >>> plt.show()
+    >>> plt = bp.line_scatter(y_scatter, y_lines, strx='x', stry='ys')
+    >>> plt.show()
+    >>> plt = bp.lines(ys)
+    >>> plt.show()
+    >>> plt = bp.lines(ys,x)
+    >>> plt.show()
+
+    """
+
+    def __init__(self, font="Arial", figure_size=(10, 7.5), types="single"):
+        """
+
+        Args:
+            font: (str), 字体。如：【Arial,DejaVu Sans,宋体+Times,宋体，Times】
+            figure_size:(tuple) 图片大小。
+            types:(str) 图片种类: 如：【single,long,part】
+        """
+        if types == "single":
+            setting_rcParams_single(font=font, figure_size=figure_size)
+        elif types == "long":
+            setting_rcParams_long(font=font, figure_size=figure_size)
+        elif types == "part":
+            setting_rcParams_part(font=font, figure_size=figure_size)
+        else:
+            setting_rcParams_single(font=font, figure_size=figure_size)
